@@ -2,8 +2,8 @@
 
 #
 # ss_poweralert_ups_status.php
-# version 0.6
-# June 21, 2009
+# version 0.8
+# November 11, 2010
 #
 # Copyright (C) 2006-2009, Eric A. Hall
 # http://www.eric-a-hall.com/
@@ -189,24 +189,9 @@ function ss_poweralert_ups_status($protocol_bundle="",
 	if ($snmp_timeout == "") {
 
 		#
-		# if the value was omitted use the Cacti SNMP timeout
+		# if the value was omitted use the global default timeout
 		#
-		if (isset($GLOBALS['config']['config_options_array']['snmp_timeout'])) {
-
-			$snmp_timeout = trim($GLOBALS['config']['config_options_array']['snmp_timeout']);
-		}
-
-		elseif (isset($GLOBALS['_SESSION']['sess_config_array']['snmp_timeout'])) {
-
-			$snmp_timeout = trim($GLOBALS['_SESSION']['sess_config_array']['snmp_timeout']);
-		}
-
-		else {
-			echo ("FATAL: Timeout not specified in SNMP parameter bundle and " .
-				"unable to determine Cacti default\n");
-			ss_nut_ups_status_syntax();
-			return;
-		}
+		$snmp_timeout = read_config_option("snmp_timeout");
 	}
 
 	if (is_numeric($snmp_timeout) == FALSE) {
@@ -217,10 +202,11 @@ function ss_poweralert_ups_status($protocol_bundle="",
 	}
 
 	#
-	# Cacti's SNMP timeout uses milliseconds, while PHP uses Net-SNMP foormat, which is
-	# typically microseconds. Normalize by multiplying the timeout value by 1000.
+	# these aren't parameters, but go ahead and out $snmp_retries and $snmp_maxoids
+	# from the global settings
 	#
-	$snmp_timeout = ($snmp_timeout * 1000);
+	$snmp_retries = read_config_option("snmp_retries");
+	$snmp_maxoids = read_config_option("max_get_size");
 
 	#
 	# 2nd function argument is $cacti_request
@@ -322,10 +308,14 @@ function ss_poweralert_ups_status($protocol_bundle="",
 			$snmp_v3_username,
 			$snmp_v3_password,
 			$snmp_port,
-			$snmp_timeout,
-			"",
-			"");
-		}
+			$snmp_timeout);
+
+		#
+		# Cacti 0.8.6 SNMP timeout used milliseconds, while PHP uses Net-SNMP foormat, which
+		# is typically microseconds. Normalize by multiplying the timeout value by 1000.
+		#
+		$snmp_timeout = ($snmp_timeout * 1000);
+	}
 
 	elseif (substr($GLOBALS['config']['cacti_version'],0,5) >= "0.8.7") {
 
@@ -342,9 +332,9 @@ function ss_poweralert_ups_status($protocol_bundle="",
 			$snmp_v3_context,
 			$snmp_port,
 			$snmp_timeout,
-			"",
-			"");
-		}
+			$snmp_retries,
+			$snmp_maxoids);
+	}
 
 	else {
 		echo ("FATAL: \"" . $GLOBALS['config']['cacti_version'] .
